@@ -19,9 +19,12 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+
+#include "config.h"
+
+#include <gtk/gtk.h>
+
 #include "gtkhwrapbox.h"
-#include <gtk/gtksignal.h>
-#include <math.h>
 
 
 /* --- prototypes --- */
@@ -94,7 +97,6 @@ gtk_hwrap_box_init (GtkHWrapBox *hwbox)
 {
   hwbox->max_child_width = 0;
   hwbox->max_child_height = 0;
-  hwbox->request_stored_height = FALSE;
 }
 
 GtkWidget*
@@ -125,55 +127,6 @@ get_child_requisition (GtkWrapBox     *wbox,
     gtk_widget_get_child_requisition (child, child_requisition);
 }
 
-#if 0
-static void
-_gtk_hwrap_box_size_request (GtkWidget      *widget,
-			     GtkRequisition *requisition)
-{
-  GtkHWrapBox *this = GTK_HWRAP_BOX (widget);
-  GtkWrapBox *wbox = GTK_WRAP_BOX (widget);
-  GtkWrapBoxChild *child;
-  guint area = 0;
-  
-  g_return_if_fail (requisition != NULL);
-  
-  /*<h2v-off>*/
-  requisition->width = 0;
-  requisition->height = 0;
-  this->max_child_width = 0;
-  this->max_child_height = 0;
-  
-  for (child = wbox->children; child; child = child->next)
-    if (GTK_WIDGET_VISIBLE (child->widget))
-      {
-	GtkRequisition child_requisition;
-	
-	gtk_widget_size_request (child->widget, &child_requisition);
-	
-	area += child_requisition.width * child_requisition.height;
-	this->max_child_width = MAX (this->max_child_width, child_requisition.width);
-	this->max_child_height = MAX (this->max_child_height, child_requisition.height);
-      }
-  if (wbox->homogeneous)
-    area = this->max_child_width * this->max_child_height * wbox->n_children;
-  
-  if (area)
-    {
-      requisition->width = sqrt (area * wbox->aspect_ratio);
-      requisition->height = area / requisition->width;
-    }
-  else
-    {
-      requisition->width = 0;
-      requisition->height = 0;
-    }
-  
-  requisition->width += GTK_CONTAINER (wbox)->border_width * 2;
-  requisition->height += GTK_CONTAINER (wbox)->border_width * 2;
-  /*<h2v-on>*/
-}
-#endif
-
 static gfloat
 get_layout_size (GtkHWrapBox *this,
 		 guint        max_width,
@@ -226,7 +179,6 @@ get_layout_size (GtkHWrapBox *this,
   return MAX (total_height, 1);
 }
 
-
 static void
 gtk_hwrap_box_size_request (GtkWidget      *widget,
 			    GtkRequisition *requisition)
@@ -236,7 +188,7 @@ gtk_hwrap_box_size_request (GtkWidget      *widget,
   GtkWrapBoxChild *child;
   gfloat ratio_dist, layout_width = 0;
   guint row_inc = 0;
-
+  
   g_return_if_fail (requisition != NULL);
   
   requisition->width = 0;
@@ -244,7 +196,6 @@ gtk_hwrap_box_size_request (GtkWidget      *widget,
   this->max_child_width = 0;
   this->max_child_height = 0;
 
-
   /* size_request all children */
   for (child = wbox->children; child; child = child->next)
     if (GTK_WIDGET_VISIBLE (child->widget))
@@ -253,8 +204,8 @@ gtk_hwrap_box_size_request (GtkWidget      *widget,
 	
 	gtk_widget_size_request (child->widget, &child_requisition);
 
-	this->max_child_width = MAX (this->max_child_width, child_requisition.width);
-	this->max_child_height = MAX (this->max_child_height, child_requisition.height);
+	this->max_child_width = MAX (this->max_child_width, (guint) child_requisition.width);
+	this->max_child_height = MAX (this->max_child_height, (guint) child_requisition.height);
       }
 
   /* figure all possible layouts */
@@ -264,27 +215,32 @@ gtk_hwrap_box_size_request (GtkWidget      *widget,
     {
       gfloat layout_height;
       gfloat ratio, dist;
-      GtkRequisition *saved_requisition;
 
       layout_width += row_inc;
       layout_height = get_layout_size (this, layout_width, &row_inc);
       ratio = layout_width / layout_height;		/*<h2v-skip>*/
       dist = MAX (ratio, wbox->aspect_ratio) - MIN (ratio, wbox->aspect_ratio);
-      if (dist < ratio_dist || 
-	  (this->request_stored_height &&
-	   layout_height == this->request_this_height_next_time))
+      if (dist < ratio_dist)
 	{
 	  ratio_dist = dist;
 	  requisition->width = layout_width;
 	  requisition->height = layout_height;
 	}
-      saved_requisition = g_new0 (GtkRequisition, 1);
-      saved_requisition->width = layout_width;
-      saved_requisition->height = layout_height;
+      
+      /* g_print ("ratio for width %d height %d = %f\n",
+	 (gint) layout_width,
+	 (gint) layout_height,
+	 ratio);
+      */
     }
   while (row_inc);
+
   requisition->width += GTK_CONTAINER (wbox)->border_width * 2; /*<h2v-skip>*/
   requisition->height += GTK_CONTAINER (wbox)->border_width * 2; /*<h2v-skip>*/
+  /* g_print ("choosen: width %d, height %d\n",
+     requisition->width,
+     requisition->height);
+  */
 }
 
 static GSList*
@@ -326,7 +282,7 @@ reverse_list_row_children (GtkWrapBox       *wbox,
 	    {
 	      get_child_requisition (wbox, child->widget, &child_requisition);
 	      if (width + wbox->hspacing + child_requisition.width > row_width ||
-		  child->forced_break)
+		  child->wrapped)
 		break;
 	      width += wbox->hspacing + child_requisition.width;
 	      *max_child_size = MAX (*max_child_size, (guint) child_requisition.height);
@@ -350,7 +306,8 @@ layout_row (GtkWrapBox    *wbox,
 	    gboolean       vexpand)
 {
   GSList *slist;
-  guint n_children = 0, n_expand_children = 0, have_expand_children = 0, total_width = 0;
+  guint n_children = 0, n_expand_children = 0, have_expand_children = 0;
+  gint total_width = 0;
   gfloat x, width, extra;
   GtkAllocation child_allocation;
   
@@ -493,7 +450,6 @@ struct _Line
   Line     *next;
 };
 
-
 static void
 layout_rows (GtkWrapBox    *wbox,
 	     GtkAllocation *area)
@@ -502,11 +458,10 @@ layout_rows (GtkWrapBox    *wbox,
   guint min_height;
   gboolean vexpand;
   GSList *slist;
+  Line *line_list = NULL;
+  guint total_height = 0, n_expand_lines = 0, n_lines = 0;
   gfloat shrink_height;
   guint children_per_line;
-  Line *line_list = NULL;
-  int total_height = 0;
-  guint n_expand_lines = 0, n_lines = 0;
   
   next_child = wbox->children;
   slist = GTK_WRAP_BOX_GET_CLASS (wbox)->rlist_line_children (wbox,
@@ -538,18 +493,11 @@ layout_rows (GtkWrapBox    *wbox,
 								  &vexpand);
       slist = g_slist_reverse (slist);
     }
-  GTK_HWRAP_BOX (wbox)->request_this_height_next_time = total_height;
-  if (!(GTK_HWRAP_BOX (wbox)->request_stored_height )) {
-    g_signal_emit_by_name (wbox, "need_reallocation", NULL);
-    GTK_HWRAP_BOX (wbox)->request_stored_height = TRUE;
-  }
-  if (total_height > area->height) {
-    shrink_height = total_height - area->height; 
-    g_signal_emit_by_name (wbox, "need_reallocation", NULL);
-  }
+  
+  if (total_height > (guint) area->height)
+    shrink_height = total_height - area->height;
   else
     shrink_height = 0;
-
   
   if (1) /* reverse lines and shrink */
     {
@@ -645,7 +593,7 @@ gtk_hwrap_box_size_allocate (GtkWidget     *widget,
 {
   GtkWrapBox *wbox = GTK_WRAP_BOX (widget);
   GtkAllocation area;
-  guint border = GTK_CONTAINER (wbox)->border_width; /*<h2v-skip>*/
+  gint border = GTK_CONTAINER (wbox)->border_width; /*<h2v-skip>*/
   
   widget->allocation = *allocation;
   area.x = allocation->x + border;
@@ -659,6 +607,6 @@ gtk_hwrap_box_size_allocate (GtkWidget     *widget,
      allocation->height);
   */
   /*<h2v-on>*/
-
+  
   layout_rows (wbox, &area);
 }
