@@ -42,9 +42,6 @@
 #include "nautilus-search-bar.h"
 #include "nautilus-window-manage-views.h"
 #include "nautilus-zoom-control.h"
-#include <eel/eel-debug.h>
-#include <eel/eel-gdk-extensions.h>
-#include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-string.h>
@@ -54,16 +51,11 @@
 #include <gtk/gtkmain.h>
 #include <gtk/gtkmenubar.h>
 #include <gtk/gtkmenuitem.h>
-#include <gtk/gtkoptionmenu.h>
-#include <gtk/gtktogglebutton.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkuimanager.h>
 #include <glib/gi18n.h>
 #include <libgnome/gnome-macros.h>
-#include <libgnome/gnome-util.h>
-#include <libgnomeui/gnome-messagebox.h>
 #include <libgnomeui/gnome-uidefs.h>
-#include <libgnomeui/gnome-window-icon.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libnautilus-private/nautilus-dnd.h>
@@ -76,15 +68,13 @@
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-program-choosing.h>
-#include <libnautilus-private/nautilus-clipboard.h>
 #include <libnautilus-private/nautilus-undo.h>
 #include <libnautilus-private/nautilus-search-directory.h>
 #include <libnautilus-private/nautilus-search-engine.h>
 #include <libnautilus-private/nautilus-signaller.h>
-#include <math.h>
-#include <sys/time.h>
 
 #define MAX_TITLE_LENGTH 180
+#define MAX_SHORTNAME_PATH 16
 
 #define SPATIAL_ACTION_PLACES               "Places"
 #define SPATIAL_ACTION_GO_TO_LOCATION       "Go to Location"
@@ -110,7 +100,6 @@ struct _NautilusSpatialWindowDetails {
 static const GtkTargetEntry location_button_drag_types[] = {
 	{ NAUTILUS_ICON_DND_GNOME_ICON_LIST_TYPE, 0, NAUTILUS_ICON_DND_GNOME_ICON_LIST },
 	{ NAUTILUS_ICON_DND_URI_LIST_TYPE, 0, NAUTILUS_ICON_DND_URI_LIST },
-	{ NAUTILUS_ICON_DND_URL_TYPE, 0, NAUTILUS_ICON_DND_URL },
 };
 
 GNOME_CLASS_BOILERPLATE (NautilusSpatialWindow, nautilus_spatial_window,
@@ -874,8 +863,8 @@ static const GtkActionEntry spatial_entries[] = {
   { "Edit Bookmarks", NULL, N_("_Edit Bookmarks"), /* name, stock id, label */
     "<control>b", N_("Display a window that allows editing the bookmarks in this menu"),
     G_CALLBACK (action_edit_bookmarks_callback) },
-  { "Search", "gtk-find", N_("_Search"), /* name, stock id, label */
-    "<control>F", N_("Search for files"),
+  { "Search", "gtk-find", N_("_Search for Files..."), /* name, stock id, label */
+    "<control>F", N_("Locate documents and folders on this computer by name or content"),
     G_CALLBACK (action_search_callback) },
 };
 
@@ -940,6 +929,8 @@ nautilus_spatial_window_instance_init (NautilusSpatialWindow *window)
 	gtk_widget_show (window->details->location_icon);
 	
 	window->details->location_label = gtk_label_new ("");
+	gtk_label_set_ellipsize (GTK_LABEL (window->details->location_label), PANGO_ELLIPSIZE_END);
+	gtk_label_set_max_width_chars (GTK_LABEL (window->details->location_label), MAX_SHORTNAME_PATH);
 	gtk_box_pack_start (GTK_BOX (hbox), window->details->location_label,
 			    FALSE, FALSE, 0);
 	gtk_widget_show (window->details->location_label);
